Linked hash map implementation.
This module provides the core LinkedHashMap type and related
functionality. The linked hash map maintains relative order while providing
O(1) access, insertion, and removal operations.
Examples
use tether_map::linked_hash_map::LinkedHashMap;
let mut map = LinkedHashMap::new();
map.insert("first", 1);
map.insert("second", 2);
// Iteration preserves insertion order
let entries: Vec<_> = map.iter().collect();
assert_eq!(entries, [(&"first", &1), (&"second", &2)]);Structs
- Cursor
Mut - A cursor for navigating and modifying a linked hash map.
- Into
Iter - An owning iterator over the entries of a
LinkedHashMap. - Iter
- An iterator over the entries of a
LinkedHashMap. - IterMut
- A mutable iterator over the entries of a
LinkedHashMap. - Linked
Hash Map - A hash map that maintains relative order using a doubly-linked list.
- Occupied
Entry - A view into an occupied entry in a
LinkedHashMap. - Removed
Entry - Represents an entry that was removed from the linked hash map.
- Vacant
Entry - A view into a vacant entry in a
LinkedHashMap. - Values
Mut - A mutable iterator over the values of a
LinkedHashMap.
Enums
- Entry
- A view into a single entry in a map, which may either be vacant or occupied.